require 'rest-client'
require 'active_support'
require 'active_support/core_ext'
require 'json'
require 'hashie'
require 'openssl'
require 'date'
require 'uri'
require 'base64'

module Polirb
  module Request

    protected

    def request(*args)
      resp = self.make_request(*args)

      hash = Hashie::Mash.new(JSON.parse(resp.body))
      raise Error.new(hash.error) if hash.error
      raise Error.new(hash.errors.join(',')) if hash.errors
      hash
    end

    def make_request(http_method, url, body={})
      raise 'Merchant Code and Authentication Code required!' unless @merchant_code && @authentication_code

      params    = URI.encode_www_form(body)

      headers = {
        'Authorization' => "Basic #{basic_auth(@merchant_code,@authentication_code)}"
      }

      if http_method == :get
        RestClient.get("#{url}?#{params}", headers)
      else
        RestClient.post(url, params, headers)
      end
    end

    private

      def basic_auth(merchant_code,authentication_code)
        Base64.encode64("#{merchant_code}:#{authentication_code}").gsub("\n","")
      end

  end
end
